@@ -1,5 +1,5 @@
 package Module::Format::Module;
-$Module::Format::Module::VERSION = '0.0.8';
+$Module::Format::Module::VERSION = '0.2.0';
 use warnings;
 use strict;
 
@@ -41,19 +41,26 @@ sub from_components
 }
 
 
-my $dash_re  = qr{(?:\w+-)*\w+};
-my $colon_re = qr{(?:\w+::)*\w+};
+my $dash_re      = qr{(?:\w+-)*\w+};
+my $colon_re     = qr{(?:\w+::)*\w+};
+my $METACPAN_REL = 'https://metacpan.org/release/';
 
-my @formats_by_priority = (
-    {
-        name  => 'rpm_dash',
-        regex => qr{\Aperl-$dash_re\z},
+sub _gen_dash_format
+{
+    my ($args) = @_;
+
+    my $prefix = $args->{prefix};
+    my $name   = $args->{name};
+
+    return +{
+        name  => $name,
+        regex => qr{\A\Q$prefix\E$dash_re\z},
         input => sub {
             my ( $class, $value ) = @_;
 
-            if ( $value !~ s{\Aperl-}{} )
+            if ( $value !~ s{\A\Q$prefix\E}{} )
             {
-                die "rpm_dash value does not start with the 'perl-' prefix.";
+                die "$name value does not start with the '$prefix' prefix.";
             }
 
             return $class->_calc_components_from_string(
@@ -62,18 +69,28 @@ my @formats_by_priority = (
         format => sub {
             my ($self) = @_;
 
-            return 'perl-' . $self->format_as('dash');
+            return $prefix . $self->format_as('dash');
         },
-    },
-    {
-        name  => 'rpm_colon',
-        regex => qr{\Aperl\($colon_re\)\z},
+    };
+}
+
+sub _gen_colon_format
+{
+    my ($args) = @_;
+
+    my $prefix = $args->{prefix};
+    my $suffix = $args->{suffix};
+    my $name   = $args->{name};
+
+    return +{
+        name  => $name,
+        regex => qr{\A\Q$prefix\E$colon_re\Q$suffix\E\z},
         input => sub {
             my ( $class, $value ) = @_;
 
-            if ( $value !~ m{\Aperl\(((?:\w+::)*\w+)\)\z} )
+            if ( $value !~ m{\A\Q$prefix\E((?:\w+::)*\w+)\Q$suffix\E\z} )
             {
-                die "Improper value for rpm_colon";
+                die "Improper value for $name";
             }
 
             return $class->_calc_components_from_string(
@@ -82,9 +99,25 @@ my @formats_by_priority = (
         format => sub {
             my ($self) = @_;
 
-            return 'perl(' . $self->format_as('colon') . ')';
+            return $prefix . $self->format_as('colon') . $suffix;
         },
-    },
+    };
+}
+
+my @formats_by_priority = (
+    _gen_dash_format(
+        {
+            name   => 'rpm_dash',
+            prefix => 'perl-',
+        }
+    ),
+    _gen_colon_format(
+        {
+            name   => 'rpm_colon',
+            prefix => 'perl(',
+            suffix => ')',
+        }
+    ),
     {
         name  => 'colon',
         regex => qr{\A$colon_re\z},
@@ -130,6 +163,19 @@ my @formats_by_priority = (
             return join( '/', @{ $self->_components() } ) . '.pm';
         },
     },
+    _gen_dash_format(
+        {
+            name   => 'metacpan_rel',
+            prefix => $METACPAN_REL,
+        }
+    ),
+    _gen_colon_format(
+        {
+            name   => 'metacpan_pod',
+            prefix => 'https://metacpan.org/pod/',
+            suffix => '',
+        }
+    ),
     {
         name   => 'debian',
         format => sub {
@@ -286,7 +332,7 @@ Module::Format::Module - encapsulates a single Perl module.
 
 =head1 VERSION
 
-version 0.0.8
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -344,7 +390,7 @@ version 0.0.8
 
 =head1 VERSION
 
-version 0.0.8
+version 0.2.0
 
 =head1 FUNCTIONS
 
@@ -394,6 +440,16 @@ Like colon only wrapped inside C<perl(...)> - useful for rpm provides for
 individual modules. E.g: C<perl(XML::RSS)>,
 C<perl(Catalyst::Plugin::Authentication)> .
 
+=item * 'metacpan_rel'
+
+A MetaCPAN release page URL, e.g:
+C<https://metacpan.org/release/Text-Sprintf-Named> , C<https://metacpan.org/release/Class-XSAccessor> .
+
+=item * 'metacpan_pod'
+
+A MetaCPAN POD page URL, e.g:
+C<https://metacpan.org/pod/Module::Format> , C<https://metacpan.org/pod/Data::ParseBinary> .
+
 =item * 'debian'
 
 Debian package format, such as C<libxml-rss-perl>,
